
:root {
	--br: 0.4rem;
	--br-inner: 0.2rem;
	--fa-fw: 1.28571429em;
	--link-focus-outline: 0.25rem dotted var(--link-fg);
	--button-focus-outline: 0.25rem dashed var(--button-focus-border);
	--input-clickable-focus-outline: 0.25rem dashed var(--input-focus-border);
	--summary-focus-outline: 0.25rem dotted var(--link-fg);
	--pre-focus-outline: 0.25rem dashed var(--link-fg);
}

/*
	GoToSocial
	Copyright (C) GoToSocial Authors admin@gotosocial.org
	SPDX-License-Identifier: AGPL-3.0-or-later

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU Affero General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU Affero General Public License for more details.

	You should have received a copy of the GNU Affero General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/***************************************
***** SECTION 0: IMPORTS AND FONTS *****
****************************************/

/*! modern-normalize v1.1.0 | MIT License | https://github.com/sindresorhus/modern-normalize */

/*
Document
========
*/

/**
Use a better box model (opinionated).
*/

*,
::before,
::after {
	box-sizing: border-box;
}

/**
Use a more readable tab size (opinionated).
*/

html {
	tab-size: 4;
}

/**
1. Correct the line height in all browsers.
2. Prevent adjustments of font size after orientation changes in iOS.
*/

html {
	line-height: 1.15; /* 1 */
	-webkit-text-size-adjust: 100%; /* 2 */
}

/*
Sections
========
*/

/**
Remove the margin in all browsers.
*/

body {
	margin: 0;
}

/**
Improve consistency of default fonts in all browsers. (https://github.com/sindresorhus/modern-normalize/issues/3)
*/

body {
	font-family:
		system-ui,
		-apple-system, /* Firefox supports this but not yet `system-ui` */
		'Segoe UI',
		Roboto,
		Helvetica,
		Arial,
		sans-serif,
		'Apple Color Emoji',
		'Segoe UI Emoji';
}

/*
Grouping content
================
*/

/**
1. Add the correct height in Firefox.
2. Correct the inheritance of border color in Firefox. (https://bugzilla.mozilla.org/show_bug.cgi?id=190655)
*/

hr {
	height: 0; /* 1 */
	color: inherit; /* 2 */
}

/*
Text-level semantics
====================
*/

/**
Add the correct text decoration in Chrome, Edge, and Safari.
*/

abbr[title] {
	-webkit-text-decoration: underline dotted;
	        text-decoration: underline dotted;
}

/**
Add the correct font weight in Edge and Safari.
*/

b,
strong {
	font-weight: bolder;
}

/**
1. Improve consistency of default fonts in all browsers. (https://github.com/sindresorhus/modern-normalize/issues/3)
2. Correct the odd 'em' font sizing in all browsers.
*/

code,
kbd,
samp,
pre {
	font-family:
		ui-monospace,
		SFMono-Regular,
		Consolas,
		'Liberation Mono',
		Menlo,
		monospace; /* 1 */
	font-size: 1em; /* 2 */
}

/**
Add the correct font size in all browsers.
*/

small {
	font-size: 80%;
}

/**
Prevent 'sub' and 'sup' elements from affecting the line height in all browsers.
*/

sub,
sup {
	font-size: 75%;
	line-height: 0;
	position: relative;
	vertical-align: baseline;
}

sub {
	bottom: -0.25em;
}

sup {
	top: -0.5em;
}

/*
Tabular data
============
*/

/**
1. Remove text indentation from table contents in Chrome and Safari. (https://bugs.chromium.org/p/chromium/issues/detail?id=999088, https://bugs.webkit.org/show_bug.cgi?id=201297)
2. Correct table border color inheritance in all Chrome and Safari. (https://bugs.chromium.org/p/chromium/issues/detail?id=935729, https://bugs.webkit.org/show_bug.cgi?id=195016)
*/

table {
	text-indent: 0; /* 1 */
	border-color: inherit; /* 2 */
}

/*
Forms
=====
*/

/**
1. Change the font styles in all browsers.
2. Remove the margin in Firefox and Safari.
*/

button,
input,
optgroup,
select,
textarea {
	font-family: inherit; /* 1 */
	font-size: 100%; /* 1 */
	line-height: 1.15; /* 1 */
	margin: 0; /* 2 */
}

/**
Remove the inheritance of text transform in Edge and Firefox.
1. Remove the inheritance of text transform in Firefox.
*/

button,
select { /* 1 */
	text-transform: none;
}

/**
Correct the inability to style clickable types in iOS and Safari.
*/

button,
[type='button'],
[type='reset'],
[type='submit'] {
	-webkit-appearance: button;
}

/**
Remove the inner border and padding in Firefox.
*/

::-moz-focus-inner {
	border-style: none;
	padding: 0;
}

/**
Restore the focus styles unset by the previous rule.
*/

:-moz-focusring {
	outline: 1px dotted ButtonText;
}

/**
Remove the additional ':invalid' styles in Firefox.
See: https://github.com/mozilla/gecko-dev/blob/2f9eacd9d3d995c937b4251a5557d95d494c9be1/layout/style/res/forms.css#L728-L737
*/

:-moz-ui-invalid {
	box-shadow: none;
}

/**
Remove the padding so developers are not caught out when they zero out 'fieldset' elements in all browsers.
*/

legend {
	padding: 0;
}

/**
Add the correct vertical alignment in Chrome and Firefox.
*/

progress {
	vertical-align: baseline;
}

/**
Correct the cursor style of increment and decrement buttons in Safari.
*/

::-webkit-inner-spin-button,
::-webkit-outer-spin-button {
	height: auto;
}

/**
1. Correct the odd appearance in Chrome and Safari.
2. Correct the outline style in Safari.
*/

[type='search'] {
	-webkit-appearance: textfield; /* 1 */
	outline-offset: -2px; /* 2 */
}

/**
Remove the inner padding in Chrome and Safari on macOS.
*/

::-webkit-search-decoration {
	-webkit-appearance: none;
}

/**
1. Correct the inability to style clickable types in iOS and Safari.
2. Change font properties to 'inherit' in Safari.
*/

::-webkit-file-upload-button {
	-webkit-appearance: button; /* 1 */
	font: inherit; /* 2 */
}

/*
Interactive
===========
*/

/*
Add the correct display in Chrome and Safari.
*/

summary {
	display: list-item;
}

/* Default to dark prism, choose light if prefers-color-scheme light */

/* PrismJS 1.30.0
https://prismjs.com/download.html#themes=prism-tomorrow&languages=markup+css+clike+javascript+bash+c+csharp+cpp+docker+elixir+erlang+go+go-module+ini+java+json+kotlin+lua+makefile+markup-templating+nginx+nix+perl+php+promql+python+r+jsx+tsx+ruby+rust+scala+sql+swift+typescript&plugins=show-invisibles+show-language+toolbar+copy-to-clipboard */

code[class*=language-],pre[class*=language-]{color:#ccc;background:0 0;font-family:Consolas,Monaco,'Andale Mono','Ubuntu Mono',monospace;font-size:1em;text-align:left;white-space:pre;word-spacing:normal;word-break:normal;word-wrap:normal;line-height:1.5;tab-size:4;-webkit-hyphens:none;hyphens:none}

pre[class*=language-]{padding:1em;margin:.5em 0;overflow:auto}

:not(pre)>code[class*=language-],pre[class*=language-]{background:#2d2d2d}

:not(pre)>code[class*=language-]{padding:.1em;border-radius:.3em;white-space:normal}

.token.block-comment,.token.cdata,.token.comment,.token.doctype,.token.prolog{color:#999}

.token.punctuation{color:#ccc}

.token.attr-name,.token.deleted,.token.namespace,.token.tag{color:#e2777a}

.token.function-name{color:#6196cc}

.token.boolean,.token.function,.token.number{color:#f08d49}

.token.class-name,.token.constant,.token.property,.token.symbol{color:#f8c555}

.token.atrule,.token.builtin,.token.important,.token.keyword,.token.selector{color:#cc99cd}

.token.attr-value,.token.char,.token.regex,.token.string,.token.variable{color:#7ec699}

.token.entity,.token.operator,.token.url{color:#67cdcc}

.token.bold,.token.important{font-weight:700}

.token.italic{font-style:italic}

.token.entity{cursor:help}

.token.inserted{color:green}

.token.cr,.token.lf,.token.space,.token.tab:not(:empty){position:relative}

.token.cr:before,.token.lf:before,.token.space:before,.token.tab:not(:empty):before{color:grey;opacity:.6;position:absolute}

.token.tab:not(:empty):before{content:'\21E5'}

.token.cr:before{content:'\240D'}

.token.crlf:before{content:'\240D\240A'}

.token.lf:before{content:'\240A'}

.token.space:before{content:'\00B7'}

div.code-toolbar{position:relative}

div.code-toolbar>.toolbar{position:absolute;z-index:10;top:.3em;right:.2em;transition:opacity .3s ease-in-out;opacity:0}

div.code-toolbar:hover>.toolbar{opacity:1}

div.code-toolbar:focus-within>.toolbar{opacity:1}

div.code-toolbar>.toolbar>.toolbar-item{display:inline-block}

div.code-toolbar>.toolbar>.toolbar-item>a{cursor:pointer}

div.code-toolbar>.toolbar>.toolbar-item>button{background:0 0;border:0;color:inherit;font:inherit;line-height:normal;overflow:visible;padding:0;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none}

div.code-toolbar>.toolbar>.toolbar-item>a,div.code-toolbar>.toolbar>.toolbar-item>button,div.code-toolbar>.toolbar>.toolbar-item>span{color:#bbb;font-size:.8em;padding:0 .5em;background:#f5f2f0;background:rgba(224,224,224,.2);box-shadow:0 2px 0 0 rgba(0,0,0,.2);border-radius:.5em}

div.code-toolbar>.toolbar>.toolbar-item>a:focus,div.code-toolbar>.toolbar>.toolbar-item>a:hover,div.code-toolbar>.toolbar>.toolbar-item>button:focus,div.code-toolbar>.toolbar>.toolbar-item>button:hover,div.code-toolbar>.toolbar>.toolbar-item>span:focus,div.code-toolbar>.toolbar>.toolbar-item>span:hover{color:inherit;text-decoration:none}

/* Override text shadow if light theme was imported before dark theme. */

code[class*="language-"],pre[class*="language-"]{text-shadow:none}

@media screen and (prefers-color-scheme: light) {
/* PrismJS 1.30.0
https://prismjs.com/download.html#themes=prism&languages=markup+css+clike+javascript+bash+c+csharp+cpp+docker+elixir+erlang+go+go-module+ini+java+json+kotlin+lua+makefile+markup-templating+nginx+nix+perl+php+promql+python+r+jsx+tsx+ruby+rust+scala+sql+swift+typescript&plugins=show-invisibles+show-language+toolbar+copy-to-clipboard */
code[class*=language-],pre[class*=language-]{color:#000;background:0 0;text-shadow:0 1px #fff;font-family:Consolas,Monaco,'Andale Mono','Ubuntu Mono',monospace;font-size:1em;text-align:left;white-space:pre;word-spacing:normal;word-break:normal;word-wrap:normal;line-height:1.5;tab-size:4;-webkit-hyphens:none;hyphens:none}code[class*=language-] ::selection,code[class*=language-]::selection,pre[class*=language-] ::selection,pre[class*=language-]::selection{text-shadow:none;background:#b3d4fc}
}

@media screen and (prefers-color-scheme: light) and print{code[class*=language-],pre[class*=language-]{text-shadow:none}}

@media screen and (prefers-color-scheme: light) {
pre[class*=language-]{padding:1em;margin:.5em 0;overflow:auto}:not(pre)>code[class*=language-],pre[class*=language-]{background:#f5f2f0}:not(pre)>code[class*=language-]{padding:.1em;border-radius:.3em;white-space:normal}.token.cdata,.token.comment,.token.doctype,.token.prolog{color:#708090}.token.punctuation{color:#999}.token.namespace{opacity:.7}.token.boolean,.token.constant,.token.deleted,.token.number,.token.property,.token.symbol,.token.tag{color:#905}.token.attr-name,.token.builtin,.token.char,.token.inserted,.token.selector,.token.string{color:#690}.language-css .token.string,.style .token.string,.token.entity,.token.operator,.token.url{color:#9a6e3a;background:hsla(0,0%,100%,.5)}.token.atrule,.token.attr-value,.token.keyword{color:#07a}.token.class-name,.token.function{color:#dd4a68}.token.important,.token.regex,.token.variable{color:#e90}.token.bold,.token.important{font-weight:700}.token.italic{font-style:italic}.token.entity{cursor:help}
.token.cr,.token.lf,.token.space,.token.tab:not(:empty){position:relative}.token.cr:before,.token.lf:before,.token.space:before,.token.tab:not(:empty):before{color:grey;opacity:.6;position:absolute}.token.tab:not(:empty):before{content:'\21E5'}.token.cr:before{content:'\240D'}.token.crlf:before{content:'\240D\240A'}.token.lf:before{content:'\240A'}.token.space:before{content:'\00B7'}
div.code-toolbar{position:relative}div.code-toolbar>.toolbar{position:absolute;z-index:10;top:.3em;right:.2em;transition:opacity .3s ease-in-out;opacity:0}div.code-toolbar:hover>.toolbar{opacity:1}div.code-toolbar:focus-within>.toolbar{opacity:1}div.code-toolbar>.toolbar>.toolbar-item{display:inline-block}div.code-toolbar>.toolbar>.toolbar-item>a{cursor:pointer}div.code-toolbar>.toolbar>.toolbar-item>button{background:0 0;border:0;color:inherit;font:inherit;line-height:normal;overflow:visible;padding:0;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none}div.code-toolbar>.toolbar>.toolbar-item>a,div.code-toolbar>.toolbar>.toolbar-item>button,div.code-toolbar>.toolbar>.toolbar-item>span{color:#bbb;font-size:.8em;padding:0 .5em;background:#f5f2f0;background:rgba(224,224,224,.2);box-shadow:0 2px 0 0 rgba(0,0,0,.2);border-radius:.5em}div.code-toolbar>.toolbar>.toolbar-item>a:focus,div.code-toolbar>.toolbar>.toolbar-item>a:hover,div.code-toolbar>.toolbar>.toolbar-item>button:focus,div.code-toolbar>.toolbar>.toolbar-item>button:hover,div.code-toolbar>.toolbar>.toolbar-item>span:focus,div.code-toolbar>.toolbar>.toolbar-item>span:hover{color:inherit;text-decoration:none}
}

/*
	GoToSocial
	Copyright (C) GoToSocial Authors admin@gotosocial.org
	SPDX-License-Identifier: AGPL-3.0-or-later

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU Affero General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
	GNU Affero General Public License for more details.

	You should have received a copy of the GNU Affero General Public License
	along with this program.	If not, see <http://www.gnu.org/licenses/>.
*/

/*
	Standard fonts (v32)

	Covered scripts:
	- Cyrillic
	- Devanagari
	- Greek
	- Vietnamese
	- Latin

	Sources:
	- https://github.com/fontsource/font-files/tree/main/fonts/google/noto-sans
	- https://fontsource.org/fonts/noto-sans
*/

/* noto-sans-cyrillic-ext-400-normal */

@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: swap;
	font-weight: 400;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-cyrillic-ext-400-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-cyrillic-ext-400-normal.woff') format('woff');
	unicode-range: U+0460-052F,U+1C80-1C8A,U+20B4,U+2DE0-2DFF,U+A640-A69F,U+FE2E-FE2F;
}

/* noto-sans-cyrillic-400-normal */

@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: swap;
	font-weight: 400;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-cyrillic-400-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-cyrillic-400-normal.woff') format('woff');
	unicode-range: U+0301,U+0400-045F,U+0490-0491,U+04B0-04B1,U+2116;
}

/* noto-sans-devanagari-400-normal */

@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: swap;
	font-weight: 400;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-devanagari-400-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-devanagari-400-normal.woff') format('woff');
	unicode-range: U+0900-097F,U+1CD0-1CF9,U+200C-200D,U+20A8,U+20B9,U+20F0,U+25CC,U+A830-A839,U+A8E0-A8FF,U+11B00-11B09;
}

/* noto-sans-greek-ext-400-normal */

@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: swap;
	font-weight: 400;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-greek-ext-400-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-greek-ext-400-normal.woff') format('woff');
	unicode-range: U+1F00-1FFF;
}

/* noto-sans-greek-400-normal */

@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: swap;
	font-weight: 400;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-greek-400-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-greek-400-normal.woff') format('woff');
	unicode-range: U+0370-0377,U+037A-037F,U+0384-038A,U+038C,U+038E-03A1,U+03A3-03FF;
}

/* noto-sans-vietnamese-400-normal */

@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: swap;
	font-weight: 400;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-vietnamese-400-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-vietnamese-400-normal.woff') format('woff');
	unicode-range: U+0102-0103,U+0110-0111,U+0128-0129,U+0168-0169,U+01A0-01A1,U+01AF-01B0,U+0300-0301,U+0303-0304,U+0308-0309,U+0323,U+0329,U+1EA0-1EF9,U+20AB;
}

/* noto-sans-latin-ext-400-normal */

@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: swap;
	font-weight: 400;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-latin-ext-400-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-latin-ext-400-normal.woff') format('woff');
	unicode-range: U+0100-02BA,U+02BD-02C5,U+02C7-02CC,U+02CE-02D7,U+02DD-02FF,U+0304,U+0308,U+0329,U+1D00-1DBF,U+1E00-1E9F,U+1EF2-1EFF,U+2020,U+20A0-20AB,U+20AD-20C0,U+2113,U+2C60-2C7F,U+A720-A7FF;
}

/* noto-sans-latin-400-normal */

@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: swap;
	font-weight: 400;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-latin-400-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-latin-400-normal.woff') format('woff');
	unicode-range: U+0000-00FF,U+0131,U+0152-0153,U+02BB-02BC,U+02C6,U+02DA,U+02DC,U+0304,U+0308,U+0329,U+2000-206F,U+20AC,U+2122,U+2191,U+2193,U+2212,U+2215,U+FEFF,U+FFFD;
}

/* noto-sans-cyrillic-ext-700-normal */

@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: swap;
	font-weight: 700;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-cyrillic-ext-700-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-cyrillic-ext-700-normal.woff') format('woff');
	unicode-range: U+0460-052F,U+1C80-1C8A,U+20B4,U+2DE0-2DFF,U+A640-A69F,U+FE2E-FE2F;
}

/* noto-sans-cyrillic-700-normal */

@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: swap;
	font-weight: 700;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-cyrillic-700-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-cyrillic-700-normal.woff') format('woff');
	unicode-range: U+0301,U+0400-045F,U+0490-0491,U+04B0-04B1,U+2116;
}

/* noto-sans-devanagari-700-normal */

@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: swap;
	font-weight: 700;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-devanagari-700-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-devanagari-700-normal.woff') format('woff');
	unicode-range: U+0900-097F,U+1CD0-1CF9,U+200C-200D,U+20A8,U+20B9,U+20F0,U+25CC,U+A830-A839,U+A8E0-A8FF,U+11B00-11B09;
}

/* noto-sans-greek-ext-700-normal */

@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: swap;
	font-weight: 700;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-greek-ext-700-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-greek-ext-700-normal.woff') format('woff');
	unicode-range: U+1F00-1FFF;
}

/* noto-sans-greek-700-normal */

@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: swap;
	font-weight: 700;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-greek-700-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-greek-700-normal.woff') format('woff');
	unicode-range: U+0370-0377,U+037A-037F,U+0384-038A,U+038C,U+038E-03A1,U+03A3-03FF;
}

/* noto-sans-vietnamese-700-normal */

@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: swap;
	font-weight: 700;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-vietnamese-700-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-vietnamese-700-normal.woff') format('woff');
	unicode-range: U+0102-0103,U+0110-0111,U+0128-0129,U+0168-0169,U+01A0-01A1,U+01AF-01B0,U+0300-0301,U+0303-0304,U+0308-0309,U+0323,U+0329,U+1EA0-1EF9,U+20AB;
}

/* noto-sans-latin-ext-700-normal */

@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: swap;
	font-weight: 700;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-latin-ext-700-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-latin-ext-700-normal.woff') format('woff');
	unicode-range: U+0100-02BA,U+02BD-02C5,U+02C7-02CC,U+02CE-02D7,U+02DD-02FF,U+0304,U+0308,U+0329,U+1D00-1DBF,U+1E00-1E9F,U+1EF2-1EFF,U+2020,U+20A0-20AB,U+20AD-20C0,U+2113,U+2C60-2C7F,U+A720-A7FF;
}

/* noto-sans-latin-700-normal */

@font-face {
	font-family: 'Noto Sans';
	font-style: normal;
	font-display: swap;
	font-weight: 700;
	src:
		local('Noto Sans'),
	url('../fonts/noto-sans/noto-sans-latin-700-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-latin-700-normal.woff') format('woff');
	unicode-range: U+0000-00FF,U+0131,U+0152-0153,U+02BB-02BC,U+02C6,U+02DA,U+02DC,U+0304,U+0308,U+0329,U+2000-206F,U+20AC,U+2122,U+2191,U+2193,U+2212,U+2215,U+FEFF,U+FFFD;
}

/* noto-sans-cyrillic-ext-400-italic */

@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: swap;
	font-weight: 400;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-cyrillic-ext-400-italic.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-cyrillic-ext-400-italic.woff') format('woff');
	unicode-range: U+0460-052F,U+1C80-1C8A,U+20B4,U+2DE0-2DFF,U+A640-A69F,U+FE2E-FE2F;
}

/* noto-sans-cyrillic-400-italic */

@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: swap;
	font-weight: 400;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-cyrillic-400-italic.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-cyrillic-400-italic.woff') format('woff');
	unicode-range: U+0301,U+0400-045F,U+0490-0491,U+04B0-04B1,U+2116;
}

/* noto-sans-devanagari-400-italic */

@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: swap;
	font-weight: 400;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-devanagari-400-italic.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-devanagari-400-italic.woff') format('woff');
	unicode-range: U+0900-097F,U+1CD0-1CF9,U+200C-200D,U+20A8,U+20B9,U+20F0,U+25CC,U+A830-A839,U+A8E0-A8FF,U+11B00-11B09;
}

/* noto-sans-greek-ext-400-italic */

@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: swap;
	font-weight: 400;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-greek-ext-400-italic.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-greek-ext-400-italic.woff') format('woff');
	unicode-range: U+1F00-1FFF;
}

/* noto-sans-greek-400-italic */

@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: swap;
	font-weight: 400;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-greek-400-italic.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-greek-400-italic.woff') format('woff');
	unicode-range: U+0370-0377,U+037A-037F,U+0384-038A,U+038C,U+038E-03A1,U+03A3-03FF;
}

/* noto-sans-vietnamese-400-italic */

@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: swap;
	font-weight: 400;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-vietnamese-400-italic.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-vietnamese-400-italic.woff') format('woff');
	unicode-range: U+0102-0103,U+0110-0111,U+0128-0129,U+0168-0169,U+01A0-01A1,U+01AF-01B0,U+0300-0301,U+0303-0304,U+0308-0309,U+0323,U+0329,U+1EA0-1EF9,U+20AB;
}

/* noto-sans-latin-ext-400-italic */

@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: swap;
	font-weight: 400;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-latin-ext-400-italic.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-latin-ext-400-italic.woff') format('woff');
	unicode-range: U+0100-02BA,U+02BD-02C5,U+02C7-02CC,U+02CE-02D7,U+02DD-02FF,U+0304,U+0308,U+0329,U+1D00-1DBF,U+1E00-1E9F,U+1EF2-1EFF,U+2020,U+20A0-20AB,U+20AD-20C0,U+2113,U+2C60-2C7F,U+A720-A7FF;
}

/* noto-sans-latin-400-italic */

@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: swap;
	font-weight: 400;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-latin-400-italic.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-latin-400-italic.woff') format('woff');
	unicode-range: U+0000-00FF,U+0131,U+0152-0153,U+02BB-02BC,U+02C6,U+02DA,U+02DC,U+0304,U+0308,U+0329,U+2000-206F,U+20AC,U+2122,U+2191,U+2193,U+2212,U+2215,U+FEFF,U+FFFD;
}

/* noto-sans-cyrillic-ext-700-italic */

@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: swap;
	font-weight: 700;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-cyrillic-ext-700-italic.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-cyrillic-ext-700-italic.woff') format('woff');
	unicode-range: U+0460-052F,U+1C80-1C8A,U+20B4,U+2DE0-2DFF,U+A640-A69F,U+FE2E-FE2F;
}

/* noto-sans-cyrillic-700-italic */

@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: swap;
	font-weight: 700;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-cyrillic-700-italic.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-cyrillic-700-italic.woff') format('woff');
	unicode-range: U+0301,U+0400-045F,U+0490-0491,U+04B0-04B1,U+2116;
}

/* noto-sans-devanagari-700-italic */

@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: swap;
	font-weight: 700;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-devanagari-700-italic.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-devanagari-700-italic.woff') format('woff');
	unicode-range: U+0900-097F,U+1CD0-1CF9,U+200C-200D,U+20A8,U+20B9,U+20F0,U+25CC,U+A830-A839,U+A8E0-A8FF,U+11B00-11B09;
}

/* noto-sans-greek-ext-700-italic */

@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: swap;
	font-weight: 700;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-greek-ext-700-italic.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-greek-ext-700-italic.woff') format('woff');
	unicode-range: U+1F00-1FFF;
}

/* noto-sans-greek-700-italic */

@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: swap;
	font-weight: 700;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-greek-700-italic.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-greek-700-italic.woff') format('woff');
	unicode-range: U+0370-0377,U+037A-037F,U+0384-038A,U+038C,U+038E-03A1,U+03A3-03FF;
}

/* noto-sans-vietnamese-700-italic */

@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: swap;
	font-weight: 700;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-vietnamese-700-italic.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-vietnamese-700-italic.woff') format('woff');
	unicode-range: U+0102-0103,U+0110-0111,U+0128-0129,U+0168-0169,U+01A0-01A1,U+01AF-01B0,U+0300-0301,U+0303-0304,U+0308-0309,U+0323,U+0329,U+1EA0-1EF9,U+20AB;
}

/* noto-sans-latin-ext-700-italic */

@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: swap;
	font-weight: 700;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-latin-ext-700-italic.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-latin-ext-700-italic.woff') format('woff');
	unicode-range: U+0100-02BA,U+02BD-02C5,U+02C7-02CC,U+02CE-02D7,U+02DD-02FF,U+0304,U+0308,U+0329,U+1D00-1DBF,U+1E00-1E9F,U+1EF2-1EFF,U+2020,U+20A0-20AB,U+20AD-20C0,U+2113,U+2C60-2C7F,U+A720-A7FF;
}

/* noto-sans-latin-700-italic */

@font-face {
	font-family: 'Noto Sans';
	font-style: italic;
	font-display: swap;
	font-weight: 700;
	src:
		local('Noto Sans'),
		url('../fonts/noto-sans/noto-sans-latin-700-italic.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-latin-700-italic.woff') format('woff');
	unicode-range: U+0000-00FF,U+0131,U+0152-0153,U+02BB-02BC,U+02C6,U+02DA,U+02DC,U+0304,U+0308,U+0329,U+2000-206F,U+20AC,U+2122,U+2191,U+2193,U+2212,U+2215,U+FEFF,U+FFFD;
}

/*
	Monospace fonts (v32)

	Covered scripts:
	- Cyrillic
	- Devanagari
	- Greek
	- Vietnamese
	- Latin

	Sources:
	- https://github.com/fontsource/font-files/tree/main/fonts/google/noto-sans-mono
	- https://fontsource.org/fonts/noto-sans-mono
*/

/* noto-sans-mono-cyrillic-ext-400-normal */

@font-face {
	font-family: 'Noto Sans Mono';
	font-style: normal;
	font-display: swap;
	font-weight: 400;
	src:
		local('Noto Sans Mono'),
		url('../fonts/noto-sans/noto-sans-mono-cyrillic-ext-400-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-mono-cyrillic-ext-400-normal.woff') format('woff');
	unicode-range: U+0460-052F,U+1C80-1C8A,U+20B4,U+2DE0-2DFF,U+A640-A69F,U+FE2E-FE2F;
}

/* noto-sans-mono-cyrillic-400-normal */

@font-face {
	font-family: 'Noto Sans Mono';
	font-style: normal;
	font-display: swap;
	font-weight: 400;
	src:
		local('Noto Sans Mono'),
		url('../fonts/noto-sans/noto-sans-mono-cyrillic-400-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-mono-cyrillic-400-normal.woff') format('woff');
	unicode-range: U+0301,U+0400-045F,U+0490-0491,U+04B0-04B1,U+2116;
}

/* noto-sans-mono-greek-ext-400-normal */

@font-face {
	font-family: 'Noto Sans Mono';
	font-style: normal;
	font-display: swap;
	font-weight: 400;
	src:
		local('Noto Sans Mono'),
		url('../fonts/noto-sans/noto-sans-mono-greek-ext-400-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-mono-greek-ext-400-normal.woff') format('woff');
	unicode-range: U+1F00-1FFF;
}

/* noto-sans-mono-greek-400-normal */

@font-face {
	font-family: 'Noto Sans Mono';
	font-style: normal;
	font-display: swap;
	font-weight: 400;
	src:
		local('Noto Sans Mono'),
		url('../fonts/noto-sans/noto-sans-mono-greek-400-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-mono-greek-400-normal.woff') format('woff');
	unicode-range: U+0370-0377,U+037A-037F,U+0384-038A,U+038C,U+038E-03A1,U+03A3-03FF;
}

/* noto-sans-mono-vietnamese-400-normal */

@font-face {
	font-family: 'Noto Sans Mono';
	font-style: normal;
	font-display: swap;
	font-weight: 400;
	src:
		local('Noto Sans Mono'),
		url('../fonts/noto-sans/noto-sans-mono-vietnamese-400-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-mono-vietnamese-400-normal.woff') format('woff');
	unicode-range: U+0102-0103,U+0110-0111,U+0128-0129,U+0168-0169,U+01A0-01A1,U+01AF-01B0,U+0300-0301,U+0303-0304,U+0308-0309,U+0323,U+0329,U+1EA0-1EF9,U+20AB;
}

/* noto-sans-mono-latin-ext-400-normal */

@font-face {
	font-family: 'Noto Sans Mono';
	font-style: normal;
	font-display: swap;
	font-weight: 400;
	src:
		local('Noto Sans Mono'),
		url('../fonts/noto-sans/noto-sans-mono-latin-ext-400-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-mono-latin-ext-400-normal.woff') format('woff');
	unicode-range: U+0100-02BA,U+02BD-02C5,U+02C7-02CC,U+02CE-02D7,U+02DD-02FF,U+0304,U+0308,U+0329,U+1D00-1DBF,U+1E00-1E9F,U+1EF2-1EFF,U+2020,U+20A0-20AB,U+20AD-20C0,U+2113,U+2C60-2C7F,U+A720-A7FF;
}

/* noto-sans-mono-latin-400-normal */

@font-face {
	font-family: 'Noto Sans Mono';
	font-style: normal;
	font-display: swap;
	font-weight: 400;
	src:
		local('Noto Sans Mono'),
		url('../fonts/noto-sans/noto-sans-mono-latin-400-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-mono-latin-400-normal.woff') format('woff');
	unicode-range: U+0000-00FF,U+0131,U+0152-0153,U+02BB-02BC,U+02C6,U+02DA,U+02DC,U+0304,U+0308,U+0329,U+2000-206F,U+20AC,U+2122,U+2191,U+2193,U+2212,U+2215,U+FEFF,U+FFFD;
}

/* noto-sans-mono-cyrillic-ext-700-normal */

@font-face {
	font-family: 'Noto Sans Mono';
	font-style: normal;
	font-display: swap;
	font-weight: 700;
	src:
		local('Noto Sans Mono'),
		url('../fonts/noto-sans/noto-sans-mono-cyrillic-ext-700-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-mono-cyrillic-ext-700-normal.woff') format('woff');
	unicode-range: U+0460-052F,U+1C80-1C8A,U+20B4,U+2DE0-2DFF,U+A640-A69F,U+FE2E-FE2F;
}

/* noto-sans-mono-cyrillic-700-normal */

@font-face {
	font-family: 'Noto Sans Mono';
	font-style: normal;
	font-display: swap;
	font-weight: 700;
	src:
		local('Noto Sans Mono'),
		url('../fonts/noto-sans/noto-sans-mono-cyrillic-700-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-mono-cyrillic-700-normal.woff') format('woff');
	unicode-range: U+0301,U+0400-045F,U+0490-0491,U+04B0-04B1,U+2116;
}

/* noto-sans-mono-greek-ext-700-normal */

@font-face {
	font-family: 'Noto Sans Mono';
	font-style: normal;
	font-display: swap;
	font-weight: 700;
	src:
		local('Noto Sans Mono'),
		url('../fonts/noto-sans/noto-sans-mono-greek-ext-700-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-mono-greek-ext-700-normal.woff') format('woff');
	unicode-range: U+1F00-1FFF;
}

/* noto-sans-mono-greek-700-normal */

@font-face {
	font-family: 'Noto Sans Mono';
	font-style: normal;
	font-display: swap;
	font-weight: 700;
	src:
		local('Noto Sans Mono'),
		url('../fonts/noto-sans/noto-sans-mono-greek-700-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-mono-greek-700-normal.woff') format('woff');
	unicode-range: U+0370-0377,U+037A-037F,U+0384-038A,U+038C,U+038E-03A1,U+03A3-03FF;
}

/* noto-sans-mono-vietnamese-700-normal */

@font-face {
	font-family: 'Noto Sans Mono';
	font-style: normal;
	font-display: swap;
	font-weight: 700;
	src:
		local('Noto Sans Mono'),
		url('../fonts/noto-sans/noto-sans-mono-vietnamese-700-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-mono-vietnamese-700-normal.woff') format('woff');
	unicode-range: U+0102-0103,U+0110-0111,U+0128-0129,U+0168-0169,U+01A0-01A1,U+01AF-01B0,U+0300-0301,U+0303-0304,U+0308-0309,U+0323,U+0329,U+1EA0-1EF9,U+20AB;
}

/* noto-sans-mono-latin-ext-700-normal */

@font-face {
	font-family: 'Noto Sans Mono';
	font-style: normal;
	font-display: swap;
	font-weight: 700;
	src:
		local('Noto Sans Mono'),
		url('../fonts/noto-sans/noto-sans-mono-latin-ext-700-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-mono-latin-ext-700-normal.woff') format('woff');
	unicode-range: U+0100-02BA,U+02BD-02C5,U+02C7-02CC,U+02CE-02D7,U+02DD-02FF,U+0304,U+0308,U+0329,U+1D00-1DBF,U+1E00-1E9F,U+1EF2-1EFF,U+2020,U+20A0-20AB,U+20AD-20C0,U+2113,U+2C60-2C7F,U+A720-A7FF;
}

/* noto-sans-mono-latin-700-normal */

@font-face {
	font-family: 'Noto Sans Mono';
	font-style: normal;
	font-display: swap;
	font-weight: 700;
	src:
		local('Noto Sans Mono'),
		url('../fonts/noto-sans/noto-sans-mono-latin-700-normal.woff2') format('woff2'),
		url('../fonts/noto-sans/noto-sans-mono-latin-700-normal.woff') format('woff');
	unicode-range: U+0000-00FF,U+0131,U+0152-0153,U+02BB-02BC,U+02C6,U+02DA,U+02DC,U+0304,U+0308,U+0329,U+2000-206F,U+20AC,U+2122,U+2191,U+2193,U+2212,U+2215,U+FEFF,U+FFFD;
}

/*
	Atkinson hyperlegible fonts

	Covered scripts:
	- Latin

	Sources:
	- https://www.brailleinstitute.org/freefont/
*/

/* atkinson-hyperlegible-400-normal */

@font-face {
	font-family: 'Atkinson Hyperlegible';
	font-style: normal;
	font-display: swap;
	font-weight: 400;
	src:
		local('Atkinson Hyperlegible'),
		url('../fonts/atkinson-hyperlegible/AtkinsonHyperlegibleNext-Regular.otf') format('opentype');
}

/* atkinson-hyperlegible-700-normal */

@font-face {
	font-family: 'Atkinson Hyperlegible';
	font-style: normal;
	font-display: swap;
	font-weight: 700;
	src:
		local('Atkinson Hyperlegible'),
		url('../fonts/atkinson-hyperlegible/AtkinsonHyperlegibleNext-Bold.otf') format('opentype');
}

/* atkinson-hyperlegible-400-italic */

@font-face {
	font-family: 'Atkinson Hyperlegible';
	font-style: italic;
	font-display: swap;
	font-weight: 400;
	src:
		local('Atkinson Hyperlegible'),
		url('../fonts/atkinson-hyperlegible/AtkinsonHyperlegibleNext-RegularItalic.otf') format('opentype');
}

/* atkinson-hyperlegible-400-italic */

@font-face {
	font-family: 'Atkinson Hyperlegible';
	font-style: italic;
	font-display: swap;
	font-weight: 700;
	src:
		local('Atkinson Hyperlegible'),
		url('../fonts/atkinson-hyperlegible/AtkinsonHyperlegibleNext-BoldItalic.otf') format('opentype');
}

/*
	Atkinson hyperlegible monospace fonts

	Covered scripts:
	- Latin

	Sources:
	- https://www.brailleinstitute.org/freefont/
*/

/* atkinson-hyperlegible-mono-400-normal */

@font-face {
	font-family: 'Atkinson Hyperlegible Mono';
	font-style: normal;
	font-display: swap;
	font-weight: 400;
	src:
		local('Atkinson Hyperlegible Mono'),
		url('../fonts/atkinson-hyperlegible/AtkinsonHyperlegibleMono-Regular.otf') format('opentype');
}

/* atkinson-hyperlegible-mono-700-normal */

@font-face {
	font-family: 'Atkinson Hyperlegible Mono';
	font-style: normal;
	font-display: swap;
	font-weight: 700;
	src:
		local('Atkinson Hyperlegible Mono'),
		url('../fonts/atkinson-hyperlegible/AtkinsonHyperlegibleMono-Bold.otf') format('opentype');
}

/* atkinson-hyperlegible-mono-400-italic */

@font-face {
	font-family: 'Atkinson Hyperlegible Mono';
	font-style: italic;
	font-display: swap;
	font-weight: 400;
	src:
		local('Atkinson Hyperlegible Mono'),
		url('../fonts/atkinson-hyperlegible/AtkinsonHyperlegibleMono-RegularItalic.otf') format('opentype');
}

/* atkinson-hyperlegible-mono-400-italic */

@font-face {
	font-family: 'Atkinson Hyperlegible Mono';
	font-style: italic;
	font-display: swap;
	font-weight: 700;
	src:
		local('Atkinson Hyperlegible Mono'),
		url('../fonts/atkinson-hyperlegible/AtkinsonHyperlegibleMono-BoldItalic.otf') format('opentype');
}

/*************************************
***** SECTION 1: HANDY VARIABLES *****
**************************************/

/*
	Standard border radius
	for nice squircles.
*/

/*
	Border radius for items that
	are framed/bordered inside
	something with $br, eg avatar,
	header img, etc.
*/

/*
	Fork-Awesome 'fa-fw' fixed icon width;
	keep in sync with https://github.com/ForkAwesome/Fork-Awesome/blob/a99579ae3e735ee70e51ed62dfcee3172b5b2db7/css/fork-awesome.css#L50
*/

/*
	Outline to give links when they're
	focused (ie., by clicking or tabbing to them).
*/

/*
	Outline to give buttons when they're
	focused (ie., by clicking or tabbing to them).
*/

/*
	Outline to give input elements like radio buttons
	and checkboxes when they're focused (ie., by clicking
	or tabbing to them).
*/

/*
	Outline to give summary elements when they're
	focused (ie., by clicking or tabbing to them).
*/

/*
	Outline to give <pre> elements when they're
	focused (ie., by clicking or tabbing to them).

	This is used when we've got a preformatted
	code block with a scroll bar inside of it.
*/

/******************************************
***** SECTION 2: BASIC GLOBAL STYLING *****
*******************************************/

html, body {
	padding: 0;
	margin: 0;
	background: var(--bg);
	color: var(--fg);
	font-family: "Noto Sans", sans-serif;
	scrollbar-color: var(--orange1) var(--gray3);
}

body {
	line-height: 1.5em;
	position: relative;
}

a {
	color: var(--link-fg);
}

a:focus-visible {
		outline: var(--link-focus-outline);
	}

/*
	Normalize margins of first and last children.
	We generally don't want to open a paragraph or
	paragraph-like element with a top margin or
	close it with a bottom margin.
*/

main p:first-child, main ol:first-child, main ul:first-child {
		margin-top: 0;
	}

main p:last-child, main ol:last-child, main ul:last-child {
		margin-bottom: 0;
	}

.button, button {
	border-radius: var(--br-inner);
	color: var(--button-fg);
	background: var(--button-bg);
	box-shadow: var(--boxshadow);
	border: var(--button-border);
	text-decoration: none;
	font-size: 1.2rem;
	font-weight: bold;
	padding: 0.5rem;
	border: none;
	cursor: pointer;
	text-align: center;
	font-family: 'Noto Sans', sans-serif;
}

.button.danger, button.danger {
		color: var(--button-danger-fg);
		background: var(--button-danger-bg);
	}

.button.danger:hover, button.danger:hover {
			background: var(--button-danger-hover-bg);
		}

.button:disabled,
	.button.disabled,
	button:disabled,
	button.disabled {
		color: var(--white2);
		background: var(--gray2);
		cursor: not-allowed;
	}

.button:disabled:hover, .button.disabled:hover, button:disabled:hover, button.disabled:hover {
			background: var(--gray3);
		}

.button:hover, button:hover {
		background: var(--button-hover-bg);
	}

.button:focus-visible, button:focus-visible {
		outline: var(--button-focus-outline);
	}

summary:focus-visible {
	outline: var(--summary-focus-outline);
}

/*
	Form styling - used in settings frontend as well.
*/

input, select, textarea, .input {
	box-sizing: border-box;
	border: 0.15rem solid var(--input-border);
	border-radius: 0.1rem;
	color: var(--fg);
	background: var(--input-bg);
	width: 100%;
	font-family: 'Noto Sans', sans-serif;
	font-size: 1rem;
	padding: 0.3rem;
}

input:focus, input:active, select:focus, select:active, textarea:focus, textarea:active, .input:focus, .input:active {
		border-color: var(--input-focus-border);
	}

input[type=checkbox]:focus-visible,
	input[type=radio]:focus-visible,
	select[type=checkbox]:focus-visible,
	select[type=radio]:focus-visible,
	textarea[type=checkbox]:focus-visible,
	textarea[type=radio]:focus-visible,
	.input[type=checkbox]:focus-visible,
	.input[type=radio]:focus-visible {
		outline: var(--input-clickable-focus-outline);
	}

input:invalid, .invalid input, select:invalid, .invalid select, textarea:invalid, .invalid textarea, .input:invalid, .invalid .input {
		border-color: var(--input-error-border);
	}

input:disabled, select:disabled, textarea:disabled, .input:disabled {
		background: transparent;
	}

input::placeholder, select::placeholder, textarea::placeholder, .input::placeholder {
		opacity: 1;
		color: var(--fg-reduced)
	}

select {
	/*
		By default this looks awful on Gnome
		Web so restyle a bit to try to make
		it consistent with firefox + chrome.
	*/
	appearance: none;
	line-height: 1.5rem;
}

/*
	Squeeze emojis so they fit inline in text.
*/

.emoji {
	width: 1.45em;
	height: 1.45em;
	margin: -0.2em 0.02em 0;
	object-fit: contain;
	vertical-align: middle;
}

@media (prefers-reduced-motion: no-preference) {

.emoji {
		/*
			Enlarge emojis on hover to give
			viewer a good look at them.
		*/
		transition: 0.1s
}
		.emoji:hover, .emoji:active {
			transform: scale(2);
			background-color: var(--bg);
			box-shadow: var(--boxshadow);
			border: var(--boxshadow-border);
			border-radius: var(--br-inner);
		}
	}

/*
	Restyle lists.
*/

ul li::marker {
		color: var(--border-accent);
	}

ol li::marker {
		font-weight: bold;
	}

/*
	Outdent block quotes a bit; use
	orange strip for left border.
*/

blockquote {
	padding: 0.5rem;
	border-left: 0.2rem solid var(--border-accent);
	margin-inline: 0;
	font-style: normal;

	/*
		Same background color we
		use for code blocks
	*/
	background-color: var(--gray2);
	border-radius: 0;
}

/*
	Nice dashed orange line
	for horizontal rules.
*/

hr {
	border: 0;
	border-top: 1px dashed var(--border-accent);
}

/*
	Don't indent definition
	lists and definitions.
*/

dl {
	margin: 0;
}

dl dd {
		margin-left: 0;
	}

label {
	cursor: pointer;
}

/*
	Set our own nice background and
	font for monospace code and pre blocks.
*/

pre, pre[class*="language-"],
code, code[class*="language-"] {
	font-family: "Noto Sans Mono", monospace;
	background-color: var(--gray2);
}

/*
	Just code on its own inside status
	content, ie, `here is some code`.
*/

code {
	padding: 0.25rem;
	border-radius: var(--br-inner);
	white-space: pre-wrap;
}

/*
	Restyle Prism code highlighting toolbar
	plugin buttons to our own button style.
	
	We have to use really specific selectors
	because of how specific prism.css is.
*/

div.code-toolbar > div.toolbar {
	margin-right: 0.5rem;
	display: flex;
	gap: 0.25rem;
}

div.code-toolbar > div.toolbar > div.toolbar-item > span, div.code-toolbar > div.toolbar > div.toolbar-item > button {
			color: var(--button-fg);
			background: var(--button-bg);
			font-weight: bold;
			box-shadow: var(--boxshadow);
		}

div.code-toolbar > div.toolbar > div.toolbar-item > span:hover, div.code-toolbar > div.toolbar > div.toolbar-item > span:focus, div.code-toolbar > div.toolbar > div.toolbar-item > button:hover, div.code-toolbar > div.toolbar > div.toolbar-item > button:focus {
				color: var(--button-fg);
			}

div.code-toolbar > div.toolbar > div.toolbar-item .copy-to-clipboard-button:hover {
			background: var(--button-hover-bg);
		}

pre, pre[class*="language-"] {
	border-radius: var(--br);
	padding: 0.5rem;
	white-space: pre;
	overflow-x: auto;
}

pre:focus, pre[class*="language-"]:focus {
		outline: var(--pre-focus-outline);
	}

/* 
		Code inside a pre block, ie.,
		
		```
		here is some code
		```
	*/

pre code, pre[class*="language-"] code {
		width: 100%;
		padding: 0;
		white-space: pre;
		overflow-x: auto;
		-webkit-overflow-scrolling: touch;
	}

/*************************************
***** SECTION 3: UTILITY CLASSES *****
**************************************/

/*
	Column header that appears at the top
	of threads, at the top of sections of
	profiles (About, Pinned Posts, etc).
*/

.col-header {
	display: grid;
	grid-template-columns: auto 1fr;
	gap: 1rem;

	justify-content: start;
	align-items: center; 

	margin: 0;
	background: var(--profile-bg);
	border-top-left-radius: var(--br);
	border-top-right-radius: var(--br);
	padding: 0.75rem;


}

.col-header.wrapping {
		display: flex;
		flex-direction: row;
		flex-wrap: wrap;
		column-gap: 1rem;
		row-gap: 0.5rem;
	}

.col-header.wrapping >:first-child {
			margin-right: auto;
		}

.col-header a {
		justify-self: end;
	}

.col-header h1, .col-header h2, .col-header h3, .col-header h4 {
		font-size: 1.2rem;
		line-height: 1.3rem;
		margin: 0;
	}

.hidden {
	display: none;
}

.nounderline {
	text-decoration: none;
}

.accent {
	color: var(--acc1);
}

.text-cutoff {
	text-overflow: ellipsis;
	overflow: hidden;
	white-space: nowrap;
}

/* 
	Class for lists that don't
	want the orange dot.
*/

.nodot li::before {
		content: initial;
	}

/*
	Forms and sign-in / sign-up / confirm pages.
*/

section.with-form form {
		display: flex;
		flex-direction: column;
		gap: 1rem;

		padding-bottom: 1rem;
		padding-top: 1rem;
	}

section.with-form form p {
			/*
				We use gap so we don't
				need top + bottom margins.
			*/
			margin-top: 0;
			margin-bottom: 0;
		}

section.with-form form label, section.with-form form input {
			padding-left: 0.2rem;
		}

section.with-form form .labelinput {
			display: flex;
			flex-direction: column;
			gap: 0.4rem;
		}

section.with-form form .checkbox {
			display: flex;
			flex-direction: row-reverse;
			gap: 0.4rem;
		}

section.with-form form .checkbox > input {
				height: 1rem;
				width: 1rem;
				align-self: center;
			}

section.with-form form .btn {
			/* Visually separate buttons a bit */
			margin-top: 1rem;
		}

/***********************************
***** SECTION 4: SHAMEFUL MESS *****
************************************/

/*
	EVERYTHING BELOW THIS POINT:
	Should be moved somewhere else
	to avoid cluttering up this file.
*/

/*
	Below section stylings are used
	in transient pages + error templates.
*/

section.error {
	word-break: break-word;
	margin-bottom: 0.5rem;
}

section.error pre {
		border: 1px solid #ff000080;
		padding: 0.5rem;
		border-radius: 0.5em;
		background-color: #ff000010;
		font-size: 1.3em;
		white-space: pre-wrap;
	}

section.oob-token code {
		background: var(--gray1);
		padding: 0.5rem;
		margin: 0;
		border-radius: 0.3rem;
	}

/*
	TODO: list and blocklist are only used
	in settings panel and on blocklist page;
	consider moving them somewhere else.
*/

.list {
	display: flex;
	flex-direction: column;
}

.list .header, .list .entry {
		padding: 0.5rem;
	}

.list .header {
		border: 0.1rem solid transparent !important; /* for alignment with .entry border padding */
		background: var(--gray1) !important;
		display: flex;
		font-weight: bold;
	}

.list .entries {
		display: flex;
		flex-direction: column;
	}

.list .entries.scrolling {
			height: 20rem;
			max-height: 20rem;
			overflow: auto;
		}

.list input[type=checkbox] {
		margin-left: 0.5rem;
	}

.list .entry {
		display: flex;
		flex-wrap: wrap;
		background: var(--list-entry-bg);
		border: 0.1rem solid transparent;
	}

.list .entry:nth-child(even) {
			background: var(--list-entry-alternate-bg);
		}

.list .entry:hover {
			background: var(--list-entry-hover-bg);
		}

.list .entry:active, .list .entry:focus, .list .entry:hover, .list .entry:target {
			border-color: var(--fg-accent);
		}

.domain-perm-list {
	box-shadow: var(--boxshadow);
}

.domain-perm-list .entry {
		display: grid;
		grid-template-columns: max(30%, 10rem) 1fr;
		gap: 0.5rem;
		align-items: start;
		border: var(--boxshadow-border);
		border-top-color: transparent;
	}

.domain-perm-list .entry > div {
			display: flex;
			align-items: center
		}

.domain-perm-list .entry .domain a {
			font-weight: bold;
			text-decoration: none;
			display: inline-block; /* so it wraps properly */
		}

.domain-perm-list .entry .public_comment p {
			margin: 0;
		}

.domain-perm-list .header .domain {
		color: var(--fg);
	}

@media screen and (max-width: 30rem) {
	.domain-perm-list .entry {
		grid-template-columns: 1fr;
		gap: 0;
	}
}

/*
	TODO: this is only used on About
	page and in settings application;
	consider moving it somewhere else.
*/

.account-card {
	display: inline-grid;
	grid-template-columns: auto 1fr;
	grid-template-rows: auto auto;
	text-decoration: none;
	gap: 0.5rem 1rem;
	border-radius: var(--br);
	padding: 0.5rem;
	min-width: 40%;
	margin-bottom: 0.3rem;

	background: var(--list-entry-bg);
}

.account-card:hover {
		background: var(--list-entry-alternate-bg);
	}

.account-card h3 {
		align-self: end;
		margin: 0;
		color: var(--fg);
	}

.account-card img.avatar {
		border-radius: 0.5rem;
		width: 5rem;
		height: 5rem;
		object-fit: cover;
		grid-row: 1 / span 2;
	}

